==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/en/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "this qtr.",
	"dateTimeFormats-appendItem-Year": "{0} {1}",
	"field-quarter-short-relative+1": "next qtr.",
	"field-tue-relative+-1": "last Tuesday",
	"field-year": "year",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minute",
	"field-tue-narrow-relative+0": "this Tu",
	"field-tue-narrow-relative+1": "next Tu",
	"field-thu-short-relative+0": "this Thu.",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "next Thu.",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-wed-narrow-relative+-1": "last W",
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-second-short": "sec.",
	"dateFormatItem-MMMd": "MMM d",
	"field-week-relative+0": "this week",
	"field-month-relative+0": "this month",
	"field-week-relative+1": "next week",
	"field-month-relative+1": "next month",
	"field-sun-narrow-relative+0": "this Su",
	"field-mon-short-relative+0": "this Mon.",
	"field-sun-narrow-relative+1": "next Su",
	"field-mon-short-relative+1": "next Mon.",
	"field-second-relative+0": "now",
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-month-short": "mo.",
	"dateFormatItem-GyMMMEd": "E, MMM d, y G",
	"dateFormatItem-yyyyMd": "M/d/y GGGGG",
	"field-day": "day",
	"field-year-relative+-1": "last year",
	"field-sat-short-relative+-1": "last Sat.",
	"field-hour-relative+0": "this hour",
	"dateFormatItem-yyyyMEd": "E, M/d/y GGGGG",
	"field-second-short-relative+0": "now",
	"field-wed-relative+-1": "last Wednesday",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "last Sa",
	"field-second": "second",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "MMMM d, y G",
	"dateFormatItem-GyMMMd": "MMM d, y G",
	"field-quarter": "quarter",
	"field-week-short": "wk.",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-tue-short-relative+0": "this Tue.",
	"field-tue-short-relative+1": "next Tue.",
	"field-month-short-relative+-1": "last mo.",
	"field-mon-relative+-1": "last Monday",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "month",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min.",
	"field-dayperiod": "am/pm",
	"field-sat-short-relative+0": "this Sat.",
	"field-sat-short-relative+1": "next Sat.",
	"dateFormat-medium": "MMM d, y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-mon-relative+0": "this Monday",
	"field-mon-relative+1": "next Monday",
	"field-year-short": "yr.",
	"field-quarter-relative+-1": "last quarter",
	"dateFormatItem-yyyyMMMd": "MMM d, y G",
	"field-sat-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-long": "{1} 'at' {0}",
	"dateFormatItem-Md": "M/d",
	"field-hour": "hour",
	"dateFormat-full": "EEEE, MMMM d, y G",
	"field-month-relative+-1": "last month",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "qtr.",
	"field-sat-narrow-relative+0": "this Sa",
	"field-fri-relative+0": "this Friday",
	"field-sat-narrow-relative+1": "next Sa",
	"field-fri-relative+1": "next Friday",
	"field-sun-short-relative+0": "this Sun.",
	"field-sun-short-relative+1": "next Sun.",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-week-relative+-1": "last week",
	"field-quarter-short-relative+-1": "last qtr.",
	"dateFormatItem-Ehm": "E h:mm a",
	"field-quarter-relative+0": "this quarter",
	"field-minute-relative+0": "this minute",
	"field-quarter-relative+1": "next quarter",
	"field-wed-short-relative+-1": "last Wed.",
	"dateFormat-short": "M/d/y GGGGG",
	"field-thu-short-relative+-1": "last Thu.",
	"dateFormatItem-yyyyMMMEd": "E, MMM d, y G",
	"field-mon-narrow-relative+-1": "last M",
	"dateTimeFormats-appendItem-Era": "{0} {1}",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-thu-narrow-relative+-1": "last Th",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "last Tu",
	"dateFormatItem-H": "HH",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "this Wed.",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "next Wed.",
	"field-sun-relative+-1": "last Sunday",
	"dateTimeFormat-full": "{1} 'at' {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "day of the week",
	"field-sat-relative+0": "this Saturday",
	"dateFormatItem-h": "h a",
	"field-sat-relative+1": "next Saturday",
	"field-week-short-relative+0": "this wk.",
	"field-week-short-relative+1": "next wk.",
	"field-month-short-relative+0": "this mo.",
	"field-month-short-relative+1": "next mo.",
	"dateFormatItem-MEd": "E, M/d",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "this Th",
	"field-thu-narrow-relative+1": "next Th",
	"field-sun-narrow-relative+-1": "last Su",
	"field-mon-short-relative+-1": "last Mon.",
	"field-thu-relative+0": "this Thursday",
	"field-thu-relative+1": "next Thursday",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "last Fri.",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-thu-relative+-1": "last Thursday",
	"field-week": "week",
	"dateFormatItem-Ed": "d E",
	"field-wed-narrow-relative+0": "this W",
	"field-wed-narrow-relative+1": "next W",
	"field-year-short-relative+0": "this yr.",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "next yr.",
	"field-fri-short-relative+0": "this Fri.",
	"field-fri-short-relative+1": "next Fri.",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"field-week-short-relative+-1": "last wk.",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "hr.",
	"field-fri-narrow-relative+-1": "last F",
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-fri-relative+-1": "last Friday",
	"field-tue-short-relative+-1": "last Tue.",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"field-mon-narrow-relative+0": "this M",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "next M",
	"field-year-short-relative+-1": "last yr.",
	"field-zone": "time zone",
	"dateFormatItem-MMMEd": "E, MMM d",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-sun-short-relative+-1": "last Sun.",
	"field-day-relative+-1": "yesterday",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "day",
	"field-era": "era",
	"field-fri-narrow-relative+0": "this F",
	"field-fri-narrow-relative+1": "next F"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/en/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "this qtr.",
	"dateTimeFormats-appendItem-Year": "{0} {1}",
	"field-quarter-short-relative+1": "next qtr.",
	"field-tue-relative+-1": "last Tuesday",
	"field-year": "year",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minute",
	"field-tue-narrow-relative+0": "this Tu",
	"field-tue-narrow-relative+1": "next Tu",
	"field-thu-short-relative+0": "this Thu.",
	"dateTimeFormat-short": "{1}, {0}",
	"field-day-relative+0": "today",
	"field-thu-short-relative+1": "next Thu.",
	"field-day-relative+1": "tomorrow",
	"field-wed-narrow-relative+-1": "last W",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-era-short": "era",
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-weekdayOfMonth": "weekday of the month",
	"field-second-short": "sec.",
	"dateFormatItem-MMMd": "MMM d",
	"field-week-relative+0": "this week",
	"field-month-relative+0": "this month",
	"field-week-relative+1": "next week",
	"field-month-relative+1": "next month",
	"field-sun-narrow-relative+0": "this Su",
	"field-mon-short-relative+0": "this Mon.",
	"field-sun-narrow-relative+1": "next Su",
	"field-mon-short-relative+1": "next Mon.",
	"field-second-relative+0": "now",
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "week of month",
	"field-month-short": "mo.",
	"dateFormatItem-GyMMMEd": "E, MMM d, y G",
	"dateFormatItem-yyyyMd": "M/d/y GGGGG",
	"field-day": "day",
	"field-dayOfYear-short": "day of yr.",
	"field-year-relative+-1": "last year",
	"field-sat-short-relative+-1": "last Sat.",
	"field-hour-relative+0": "this hour",
	"dateFormatItem-yyyyMEd": "E, M/d/y GGGGG",
	"field-second-short-relative+0": "now",
	"field-wed-relative+-1": "last Wednesday",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "last Sa",
	"field-second": "second",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "MMMM d, y G",
	"dateFormatItem-GyMMMd": "MMM d, y G",
	"field-quarter": "quarter",
	"field-week-short": "wk.",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-tue-short-relative+0": "this Tue.",
	"field-tue-short-relative+1": "next Tue.",
	"field-month-short-relative+-1": "last mo.",
	"field-mon-relative+-1": "last Monday",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "month",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min.",
	"field-dayperiod": "am/pm",
	"field-sat-short-relative+0": "this Sat.",
	"field-sat-short-relative+1": "next Sat.",
	"dateFormat-medium": "MMM d, y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-mon-relative+0": "this Monday",
	"field-mon-relative+1": "next Monday",
	"field-year-short": "yr.",
	"field-quarter-relative+-1": "last quarter",
	"dateFormatItem-yyyyMMMd": "MMM d, y G",
	"field-dayOfYear": "day of year",
	"field-sat-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-long": "{1} 'at' {0}",
	"dateFormatItem-Md": "M/d",
	"field-hour": "hour",
	"dateFormat-full": "EEEE, MMMM d, y G",
	"field-month-relative+-1": "last month",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "qtr.",
	"field-sat-narrow-relative+0": "this Sa",
	"field-fri-relative+0": "this Friday",
	"field-sat-narrow-relative+1": "next Sa",
	"field-fri-relative+1": "next Friday",
	"dateFormatItem-EBhm": "E h:mm B",
	"field-sun-short-relative+0": "this Sun.",
	"field-sun-short-relative+1": "next Sun.",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-week-relative+-1": "last week",
	"field-quarter-short-relative+-1": "last qtr.",
	"dateFormatItem-Ehm": "E h:mm a",
	"field-quarter-relative+0": "this quarter",
	"field-minute-relative+0": "this minute",
	"field-quarter-relative+1": "next quarter",
	"field-wed-short-relative+-1": "last Wed.",
	"dateFormat-short": "M/d/y GGGGG",
	"dateFormatItem-Bh": "h B",
	"field-thu-short-relative+-1": "last Thu.",
	"dateFormatItem-yyyyMMMEd": "E, MMM d, y G",
	"field-mon-narrow-relative+-1": "last M",
	"dateTimeFormats-appendItem-Era": "{0} {1}",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-thu-narrow-relative+-1": "last Th",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "last Tu",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "wk. of mo.",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "this Wed.",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "next Wed.",
	"field-sun-relative+-1": "last Sunday",
	"dateTimeFormat-full": "{1} 'at' {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "day of the week",
	"field-sat-relative+0": "this Saturday",
	"dateFormatItem-h": "h a",
	"field-sat-relative+1": "next Saturday",
	"field-week-short-relative+0": "this wk.",
	"field-week-short-relative+1": "next wk.",
	"field-month-short-relative+0": "this mo.",
	"field-month-short-relative+1": "next mo.",
	"field-weekdayOfMonth-short": "wkday. of mo.",
	"dateFormatItem-MEd": "E, M/d",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "this Th",
	"field-sun-narrow-relative+-1": "last Su",
	"field-mon-short-relative+-1": "last Mon.",
	"field-thu-narrow-relative+1": "next Th",
	"field-thu-relative+0": "this Thursday",
	"field-thu-relative+1": "next Thursday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Fri.",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-thu-relative+-1": "last Thursday",
	"field-week": "week",
	"dateFormatItem-Ed": "d E",
	"field-wed-narrow-relative+0": "this W",
	"field-wed-narrow-relative+1": "next W",
	"field-year-short-relative+0": "this yr.",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-dayperiod-short": "am/pm",
	"field-year-short-relative+1": "next yr.",
	"field-fri-short-relative+0": "this Fri.",
	"field-fri-short-relative+1": "next Fri.",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"field-week-short-relative+-1": "last wk.",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "hr.",
	"field-zone-short": "zone",
	"field-fri-narrow-relative+-1": "last F",
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-fri-relative+-1": "last Friday",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-tue-short-relative+-1": "last Tue.",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"field-mon-narrow-relative+0": "this M",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "next M",
	"field-year-short-relative+-1": "last yr.",
	"field-zone": "time zone",
	"dateFormatItem-MMMEd": "E, MMM d",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-sun-short-relative+-1": "last Sun.",
	"field-day-relative+-1": "yesterday",
	"field-weekday-short": "day of wk.",
	"dateFormatItem-Bhm": "h:mm B",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "day",
	"field-era": "era",
	"field-fri-narrow-relative+0": "this F",
	"field-fri-narrow-relative+1": "next F"
}
//end v1.x content
);
